Package: Nestimate
Title: Network Estimation, Bootstrap, and Higher-Order Analysis
Version: 0.8.0
Authors@R: c(
    person("Mohammed", "Saqr", email = "saqr@saqr.me", role = c("aut", "cre", "cph")),
    person("Sonsoles", "López-Pernas", email = "sonsoles.lopez@uef.fi", role = "aut"),
    person("Kamila", "Misiejuk", email = "kamila.misiejuk@fernuni-hagen.de", role = "aut")
    )
Description: Estimate, compare, and analyze dynamic and psychological networks
    using a unified interface. Provides transition network analysis
    estimation (transition, frequency, co-occurrence, attention-weighted)
    Saqr et al. (2025) <doi:10.1145/3706468.3706513>, psychological
    network methods (correlation, partial correlation, 'graphical lasso',
    'Ising') Saqr, Beck, and Lopez-Pernas (2024)
    <doi:10.1007/978-3-031-54464-4_19>,
    and higher-order network methods including higher-order networks,
    higher-order network embedding, hyper-path anomaly, and multi-order
    generative model. Supports bootstrap inference, permutation testing,
    split-half reliability, centrality stability analysis, mixed Markov
    models, multi-cluster multi-layer networks and clustering.
License: MIT + file LICENSE
URL: https://github.com/mohsaqr/Nestimate, https://saqr.me/Nestimate/
BugReports: https://github.com/mohsaqr/Nestimate/issues
Language: en-US
Encoding: UTF-8
RoxygenNote: 7.3.3
Imports: ggplot2, data.table, cluster, scales, brglm2, nnet
Suggests: testthat (>= 3.0.0), igraph, glmnet, lavaan, stringdist,
        gridExtra, lme4, corpcor, Matrix, cograph (>= 2.4.4),
        ggfittext, knitr, rmarkdown, tna
Config/testthat/edition: 3
Depends: R (>= 4.1.0)
LazyData: true
VignetteBuilder: knitr
NeedsCompilation: no
Packaged: 2026-07-10 17:45:15 UTC; mohammedsaqr
Author: Mohammed Saqr [aut, cre, cph],
  Sonsoles López-Pernas [aut],
  Kamila Misiejuk [aut]
Maintainer: Mohammed Saqr <saqr@saqr.me>
Repository: CRAN
Date/Publication: 2026-07-10 23:10:22 UTC
Built: R 4.4.3; ; 2026-07-11 00:50:13 UTC; unix
