# Generated by roxygen2: do not edit by hand

S3method(as.data.frame,net_cluster_diagnostics)
S3method(as.data.frame,state_freq)
S3method(as_htna,default)
S3method(as_htna,mcml)
S3method(as_netdifference,default)
S3method(as_netdifference,net_bayes)
S3method(as_netdifference,netdifference)
S3method(as_netobject,cograph_network)
S3method(as_netobject,default)
S3method(as_netobject,netobject)
S3method(as_netobject,psychnet)
S3method(as_networks,default)
S3method(as_networks,mcml_pc)
S3method(as_tna,default)
S3method(as_tna,mcml)
S3method(cluster_diagnostics,default)
S3method(cluster_diagnostics,net_clustering)
S3method(cluster_diagnostics,net_mmm)
S3method(cluster_diagnostics,net_mmm_clustering)
S3method(cluster_diagnostics,netobject_group)
S3method(coefs,default)
S3method(coefs,net_mlvar)
S3method(compare_model,cograph_network)
S3method(compare_model,matrix)
S3method(compare_model,netobject)
S3method(compare_model,netobject_group)
S3method(mosaic_plot,default)
S3method(mosaic_plot,htna)
S3method(mosaic_plot,matrix)
S3method(mosaic_plot,mcml)
S3method(mosaic_plot,netobject)
S3method(mosaic_plot,netobject_group)
S3method(mosaic_plot,table)
S3method(net_deprune,default)
S3method(net_deprune,netobject)
S3method(net_deprune,netobject_group)
S3method(net_edge_betweenness,default)
S3method(net_edge_betweenness,netobject)
S3method(net_edge_betweenness,netobject_group)
S3method(net_prune,default)
S3method(net_prune,netobject)
S3method(net_prune,netobject_group)
S3method(net_pruning_details,default)
S3method(net_pruning_details,netobject)
S3method(net_pruning_details,netobject_group)
S3method(net_reprune,default)
S3method(net_reprune,netobject)
S3method(net_reprune,netobject_group)
S3method(pathways,net_association_rules)
S3method(pathways,net_hon)
S3method(pathways,net_hypa)
S3method(pathways,net_link_prediction)
S3method(pathways,net_mogen)
S3method(pathways,netobject)
S3method(plot,boot_glasso)
S3method(plot,chain_structure)
S3method(plot,cluster_choice)
S3method(plot,magnitude_difference)
S3method(plot,mcml_pc)
S3method(plot,mmm_compare)
S3method(plot,mosaic_analysis)
S3method(plot,net_association_rules)
S3method(plot,net_bayes)
S3method(plot,net_casedrop_reliability)
S3method(plot,net_casedrop_reliability_group)
S3method(plot,net_centrality)
S3method(plot,net_centrality_group)
S3method(plot,net_cluster_diagnostics)
S3method(plot,net_clustering)
S3method(plot,net_comparison)
S3method(plot,net_edge_betweenness)
S3method(plot,net_gimme)
S3method(plot,net_honem)
S3method(plot,net_markov_order)
S3method(plot,net_markov_stability)
S3method(plot,net_mmm)
S3method(plot,net_mmm_clustering)
S3method(plot,net_mogen)
S3method(plot,net_mpt)
S3method(plot,net_path_dependence)
S3method(plot,net_reliability)
S3method(plot,net_sequence_comparison)
S3method(plot,net_stability)
S3method(plot,net_transition_entropy)
S3method(plot,net_vertex_bootstrap)
S3method(plot,net_vertex_comparison)
S3method(plot,pc_loading_stability)
S3method(plot,persistence_landscape)
S3method(plot,persistent_homology)
S3method(plot,q_analysis)
S3method(plot,simplicial_complex)
S3method(plot,state_freq)
S3method(plot_state_frequencies,default)
S3method(plot_state_frequencies,htna)
S3method(plot_state_frequencies,mcml)
S3method(plot_state_frequencies,netobject)
S3method(plot_state_frequencies,netobject_group)
S3method(predictability,netobject)
S3method(predictability,netobject_group)
S3method(predictability,netobject_ml)
S3method(print,boot_glasso)
S3method(print,chain_structure)
S3method(print,chain_structure_group)
S3method(print,cluster_choice)
S3method(print,hypergraph_measures)
S3method(print,magnitude_difference)
S3method(print,mcml)
S3method(print,mcml_layer)
S3method(print,mcml_pc)
S3method(print,mmm_compare)
S3method(print,mosaic_analysis)
S3method(print,nestimate_data)
S3method(print,nestimate_facet_list)
S3method(print,nestimate_facet_plot)
S3method(print,net_association_rules)
S3method(print,net_bayes)
S3method(print,net_bayes_group)
S3method(print,net_bootstrap)
S3method(print,net_bootstrap_group)
S3method(print,net_casedrop_reliability)
S3method(print,net_casedrop_reliability_group)
S3method(print,net_certainty)
S3method(print,net_cluster_diagnostics)
S3method(print,net_clustering)
S3method(print,net_comparison)
S3method(print,net_gimme)
S3method(print,net_hon)
S3method(print,net_honem)
S3method(print,net_hypa)
S3method(print,net_hypergraph)
S3method(print,net_link_prediction)
S3method(print,net_markov_order)
S3method(print,net_markov_order_group)
S3method(print,net_markov_stability)
S3method(print,net_markov_stability_group)
S3method(print,net_mlvar)
S3method(print,net_mmm)
S3method(print,net_mmm_clustering)
S3method(print,net_mogen)
S3method(print,net_mpt)
S3method(print,net_mpt_group)
S3method(print,net_nct)
S3method(print,net_path_dependence)
S3method(print,net_permutation)
S3method(print,net_permutation_group)
S3method(print,net_pruning_details)
S3method(print,net_reliability)
S3method(print,net_sequence_comparison)
S3method(print,net_stability)
S3method(print,net_stability_group)
S3method(print,net_transition_entropy)
S3method(print,net_transition_entropy_group)
S3method(print,net_vertex_bootstrap)
S3method(print,net_vertex_comparison)
S3method(print,netdifference)
S3method(print,netobject)
S3method(print,netobject_group)
S3method(print,netobject_ml)
S3method(print,pc_loading_stability)
S3method(print,persistence_landscape)
S3method(print,persistent_homology)
S3method(print,q_analysis)
S3method(print,simplicial_complex)
S3method(print,state_freq)
S3method(print,summary.net_casedrop_reliability_group)
S3method(print,summary.net_mpt)
S3method(print,summary.net_path_dependence)
S3method(print,summary.net_transition_entropy)
S3method(print,summary.netobject)
S3method(print,summary.netobject_group)
S3method(print,summary_chain_structure)
S3method(print,tidy_covariates)
S3method(print,wtna_boot_mixed)
S3method(print,wtna_mixed)
S3method(print,wtna_perm_mixed)
S3method(rename_models,default)
S3method(rename_models,netobject_group)
S3method(state_distribution,default)
S3method(state_distribution,htna)
S3method(state_distribution,mcml)
S3method(state_distribution,netobject)
S3method(state_distribution,netobject_group)
S3method(summary,boot_glasso)
S3method(summary,chain_structure)
S3method(summary,chain_structure_group)
S3method(summary,cluster_choice)
S3method(summary,mcml)
S3method(summary,mcml_pc)
S3method(summary,mmm_compare)
S3method(summary,mosaic_analysis)
S3method(summary,nest_initial_probs)
S3method(summary,nest_transition_counts)
S3method(summary,nest_transition_matrix)
S3method(summary,net_association_rules)
S3method(summary,net_bayes)
S3method(summary,net_bayes_group)
S3method(summary,net_bootstrap)
S3method(summary,net_bootstrap_group)
S3method(summary,net_casedrop_reliability)
S3method(summary,net_casedrop_reliability_group)
S3method(summary,net_clustering)
S3method(summary,net_gimme)
S3method(summary,net_hon)
S3method(summary,net_honem)
S3method(summary,net_hypa)
S3method(summary,net_hypergraph)
S3method(summary,net_link_prediction)
S3method(summary,net_markov_order)
S3method(summary,net_markov_stability)
S3method(summary,net_mlvar)
S3method(summary,net_mmm)
S3method(summary,net_mogen)
S3method(summary,net_mpt)
S3method(summary,net_nct)
S3method(summary,net_path_dependence)
S3method(summary,net_permutation)
S3method(summary,net_permutation_group)
S3method(summary,net_reliability)
S3method(summary,net_sequence_comparison)
S3method(summary,net_stability)
S3method(summary,net_stability_group)
S3method(summary,net_transition_entropy)
S3method(summary,net_vertex_bootstrap)
S3method(summary,net_vertex_comparison)
S3method(summary,netobject)
S3method(summary,netobject_group)
S3method(summary,wtna_boot_mixed)
S3method(summary,wtna_perm_mixed)
export(action_to_onehot)
export(actor_endpoints)
export(as_htna)
export(as_netdifference)
export(as_netobject)
export(as_networks)
export(as_tna)
export(association_rules)
export(bayes_compare)
export(betti_numbers)
export(bipartite_groups)
export(boot_glasso)
export(bootstrap_network)
export(bottleneck_distance)
export(build_atna)
export(build_clusters)
export(build_cna)
export(build_cor)
export(build_ftna)
export(build_gimme)
export(build_glasso)
export(build_hon)
export(build_honem)
export(build_hypa)
export(build_hypergraph)
export(build_ising)
export(build_mcml)
export(build_mcml_pc)
export(build_mlvar)
export(build_mmm)
export(build_mogen)
export(build_network)
export(build_pcor)
export(build_simplicial)
export(build_tna)
export(casedrop_reliability)
export(centrality_stability)
export(certainty)
export(chain_structure)
export(clique_expansion)
export(cluster_choice)
export(cluster_data)
export(cluster_diagnostics)
export(cluster_mmm)
export(cluster_network)
export(cluster_summary)
export(coefs)
export(compare_mmm)
export(compare_model)
export(convert_sequence_format)
export(cooccurrence)
export(distribution_plot)
export(estimate_network)
export(euler_characteristic)
export(evaluate_links)
export(extract_edges)
export(extract_initial_probs)
export(extract_transition_matrix)
export(frequencies)
export(get_estimator)
export(hypergraph_centrality)
export(hypergraph_measures)
export(list_estimators)
export(loading_stability)
export(long_to_wide)
export(magnitude_difference)
export(mark_first_state)
export(mark_terminal_state)
export(markov_order_test)
export(markov_stability)
export(mogen_transitions)
export(mosaic_analysis)
export(mosaic_plot)
export(nct)
export(net_aggregate_weights)
export(net_centrality)
export(net_deprune)
export(net_edge_betweenness)
export(net_prune)
export(net_pruning_details)
export(net_reprune)
export(network_reliability)
export(passage_time)
export(path_counts)
export(path_dependence)
export(pathways)
export(permutation)
export(persistence_landscape)
export(persistent_homology)
export(plot_mosaic)
export(plot_state_frequencies)
export(predict_links)
export(predictability)
export(prepare)
export(prepare_for_tna)
export(prepare_onehot)
export(q_analysis)
export(register_estimator)
export(remove_estimator)
export(rename_models)
export(sequence_compare)
export(sequence_plot)
export(simplicial_degree)
export(state_distribution)
export(state_frequencies)
export(subtract_networks)
export(transition_entropy)
export(validate_netobject)
export(verify_simplicial)
export(vertex_bootstrap)
export(vertex_compare)
export(wide_to_long)
export(wtna)
if (getRversion() >= "3.6.0") S3method(knitr::knit_print, nestimate_facet_list)
if (getRversion() >= "3.6.0") S3method(knitr::knit_print, state_freq)
import(ggplot2)
importFrom(data.table,data.table)
importFrom(data.table,rbindlist)
importFrom(data.table,setDT)
importFrom(data.table,setorderv)
importFrom(parallel,mclapply)
importFrom(stats,aggregate)
importFrom(stats,approx)
importFrom(stats,ave)
importFrom(stats,chisq.test)
importFrom(stats,cmdscale)
importFrom(stats,coef)
importFrom(stats,complete.cases)
importFrom(stats,confint)
importFrom(stats,cor)
importFrom(stats,cov)
importFrom(stats,cov2cor)
importFrom(stats,ecdf)
importFrom(stats,fitted)
importFrom(stats,lm)
importFrom(stats,median)
importFrom(stats,na.omit)
importFrom(stats,p.adjust)
importFrom(stats,pbeta)
importFrom(stats,pnorm)
importFrom(stats,predict)
importFrom(stats,pt)
importFrom(stats,qbeta)
importFrom(stats,qnorm)
importFrom(stats,qt)
importFrom(stats,quantile)
importFrom(stats,rbeta)
importFrom(stats,rbinom)
importFrom(stats,reshape)
importFrom(stats,residuals)
importFrom(stats,rnorm)
importFrom(stats,rpois)
importFrom(stats,runif)
importFrom(stats,sd)
importFrom(stats,setNames)
importFrom(stats,spline)
importFrom(stats,symnum)
importFrom(stats,var)
importFrom(utils,capture.output)
importFrom(utils,combn)
importFrom(utils,head)
importFrom(utils,modifyList)
importFrom(utils,tail)
