% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/extraction.R
\name{extraction}
\alias{extraction}
\title{Model Extraction Functions}
\description{
Functions for extracting components from TNA model objects.
}
\keyword{internal}
