% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/bootstrap_network.R
\name{summary.net_bootstrap_group}
\alias{summary.net_bootstrap_group}
\title{Summary Method for net_bootstrap_group}
\usage{
\method{summary}{net_bootstrap_group}(object, ...)
}
\arguments{
\item{object}{A \code{net_bootstrap_group} object.}

\item{...}{Ignored.}
}
\value{
A data frame with group, edge, and bootstrap statistics columns.
}
\description{
Summary Method for net_bootstrap_group
}
\examples{
seqs <- data.frame(V1 = c("A","B","A","C"), V2 = c("B","C","C","A"),
  V3 = c("C","A","B","B"), grp = c("X","X","Y","Y"))
nets <- build_network(seqs, method = "relative", group = "grp")
boot <- bootstrap_network(nets, iter = 10)
summary(boot)
\donttest{
set.seed(1)
seqs <- data.frame(
  V1 = c("A","B","A","C","B","A"),
  V2 = c("B","C","B","A","C","B"),
  V3 = c("C","A","C","B","A","C"),
  grp = c("X","X","X","Y","Y","Y")
)
nets <- build_network(seqs, method = "relative", group = "grp")
boot <- bootstrap_network(nets, iter = 20)
summary(boot)
}
}
