% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/mcml.R
\name{.auto_detect_clusters}
\alias{.auto_detect_clusters}
\title{Auto-detect clusters from netobject}
\usage{
.auto_detect_clusters(x)
}
\description{
Auto-detect clusters from netobject
}
\keyword{internal}
