% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/markov_order.R
\name{print.net_markov_order_group}
\alias{print.net_markov_order_group}
\title{Print method for \code{net_markov_order_group}}
\usage{
\method{print}{net_markov_order_group}(x, ...)
}
\arguments{
\item{x}{A \code{net_markov_order_group} (named list of \code{net_markov_order}
results, one per group).}

\item{...}{Forwarded to \code{print.net_markov_order} for each element.}
}
\value{
\code{x} invisibly.
}
\description{
Print method for \code{net_markov_order_group}
}
