% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/mlvar.R
\name{summary.net_mlvar}
\alias{summary.net_mlvar}
\title{Summary method for net_mlvar}
\usage{
\method{summary}{net_mlvar}(object, ...)
}
\arguments{
\item{object}{A \code{net_mlvar} object returned by \code{\link[=build_mlvar]{build_mlvar()}}.}

\item{...}{Unused; present for S3 consistency.}
}
\value{
Invisibly returns \code{object}.
}
\description{
Summary method for net_mlvar
}
\examples{
\dontrun{
d <- simulate_data("mlvar", seed = 1)
fit <- build_mlvar(d, vars = attr(d, "vars"),
                   id = "id", day = "day", beep = "beep")
print(fit)
summary(fit)
}

}
