% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/transition_entropy.R
\name{print.net_transition_entropy_group}
\alias{print.net_transition_entropy_group}
\title{Print method for \code{net_transition_entropy_group}}
\usage{
\method{print}{net_transition_entropy_group}(x, ...)
}
\arguments{
\item{x}{A \code{net_transition_entropy_group}.}

\item{...}{Forwarded to \code{print.net_transition_entropy}.}
}
\value{
\code{x} invisibly.
}
\description{
Print method for \code{net_transition_entropy_group}
}
