% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/mmm.R
\name{plot.mmm_compare}
\alias{plot.mmm_compare}
\title{Plot Method for mmm_compare}
\usage{
\method{plot}{mmm_compare}(x, ...)
}
\arguments{
\item{x}{An \code{mmm_compare} object.}

\item{...}{Additional arguments (ignored).}
}
\value{
A \code{ggplot} object, invisibly.
}
\description{
Plot Method for mmm_compare
}
\examples{
seqs <- data.frame(V1 = sample(c("A","B","C"), 30, TRUE),
                   V2 = sample(c("A","B","C"), 30, TRUE))
cmp <- compare_mmm(seqs, k = 2:3, n_starts = 1, max_iter = 10, seed = 1)
plot(cmp)
\donttest{
set.seed(1)
seqs <- data.frame(
  V1 = sample(c("A","B","C"), 30, TRUE),
  V2 = sample(c("A","B","C"), 30, TRUE),
  V3 = sample(c("A","B","C"), 30, TRUE)
)
cmp <- compare_mmm(seqs, k = 2:3, n_starts = 5, seed = 1)
plot(cmp)
}

}
