% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/association_rules.R
\name{plot.net_association_rules}
\alias{plot.net_association_rules}
\title{Plot Method for net_association_rules}
\usage{
\method{plot}{net_association_rules}(x, ...)
}
\arguments{
\item{x}{A \code{net_association_rules} object.}

\item{...}{Additional arguments passed to \code{ggplot2} functions.}
}
\value{
A \code{ggplot} object, invisibly.
}
\description{
Scatter plot of association rules: support vs confidence, with point
size proportional to lift.
}
\examples{
trans <- list(c("A","B","C"), c("A","B"), c("B","C","D"),
              c("A","C","D"), c("A","B","D"), c("B","C"))
rules <- association_rules(trans, min_support = 0.3, min_confidence = 0.3,
                           min_lift = 0)
plot(rules)

}
