% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/sequence_compare.R
\name{print.net_sequence_comparison}
\alias{print.net_sequence_comparison}
\title{Print Method for net_sequence_comparison}
\usage{
\method{print}{net_sequence_comparison}(x, ...)
}
\arguments{
\item{x}{A \code{net_sequence_comparison} object.}

\item{...}{Additional arguments (ignored).}
}
\value{
The input object, invisibly.
}
\description{
Print Method for net_sequence_comparison
}
\examples{
seqs <- data.frame(
  V1 = sample(LETTERS[1:4], 60, TRUE),
  V2 = sample(LETTERS[1:4], 60, TRUE),
  V3 = sample(LETTERS[1:4], 60, TRUE),
  V4 = sample(LETTERS[1:4], 60, TRUE)
)
grp <- rep(c("X", "Y"), 30)
net <- build_network(seqs, method = "relative")
res <- sequence_compare(net, group = grp, sub = 2:3, test = "chisq")

}
