% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/mcml.R
\name{.detect_mcml_input}
\alias{.detect_mcml_input}
\title{Detect input type for build_mcml}
\usage{
.detect_mcml_input(x)
}
\description{
Detect input type for build_mcml
}
\keyword{internal}
