% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/data_conversion.R
\name{data_conversion}
\alias{data_conversion}
\title{Data Format Conversion Functions}
\description{
Functions for converting between wide and long data formats commonly used
in Temporal Network Analysis.
}
\keyword{internal}
