% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/mlvar.R
\name{print.net_mlvar}
\alias{print.net_mlvar}
\title{Print method for net_mlvar}
\usage{
\method{print}{net_mlvar}(x, ...)
}
\arguments{
\item{x}{A \code{net_mlvar} object returned by \code{\link[=build_mlvar]{build_mlvar()}}.}

\item{...}{Unused; present for S3 consistency.}
}
\value{
Invisibly returns \code{x}.
}
\description{
Print method for net_mlvar
}
\examples{
\dontrun{
d <- simulate_data("mlvar", seed = 1)
fit <- build_mlvar(d, vars = attr(d, "vars"),
                   id = "id", day = "day", beep = "beep")
print(fit)
summary(fit)
}

}
