% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/hypa.R
\name{print.net_hypa}
\alias{print.net_hypa}
\title{Print Method for net_hypa}
\usage{
\method{print}{net_hypa}(x, ...)
}
\arguments{
\item{x}{A \code{net_hypa} object.}

\item{...}{Additional arguments (ignored).}
}
\value{
The input object, invisibly.
}
\description{
Print Method for net_hypa
}
\examples{
seqs <- list(c("A","B","C"), c("B","C","A"), c("A","C","B"), c("A","B","C"))
hyp <- build_hypa(seqs, k = 2)
print(hyp)

\donttest{
seqs <- data.frame(
  V1 = c("A","B","C","A","B","C","A","B","C","A"),
  V2 = c("B","C","A","B","C","A","B","C","A","B"),
  V3 = c("C","A","B","C","A","B","C","A","B","C"),
  V4 = c("A","B","C","A","B","C","A","B","C","A")
)
hypa <- build_hypa(seqs, k = 2L)
print(hypa)
}

}
