% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/mcml.R
\name{.build_from_transitions}
\alias{.build_from_transitions}
\title{Build cluster_summary from transition vectors}
\usage{
.build_from_transitions(
  from_nodes,
  to_nodes,
  weights,
  cluster_lookup,
  cluster_list,
  method,
  type,
  directed,
  compute_within,
  data = NULL
)
}
\description{
Build cluster_summary from transition vectors
}
\keyword{internal}
