% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/vertex_bootstrap.R
\name{print.net_vertex_bootstrap}
\alias{print.net_vertex_bootstrap}
\title{Print a Vertex Bootstrap Result}
\usage{
\method{print}{net_vertex_bootstrap}(x, digits = 3, ...)
}
\arguments{
\item{x}{A \code{net_vertex_bootstrap} object.}

\item{digits}{Number of digits to display (default 3).}

\item{...}{Additional arguments (ignored).}
}
\value{
\code{x}, invisibly.
}
\description{
Print a Vertex Bootstrap Result
}
