% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/honem.R
\name{print.net_honem}
\alias{print.net_honem}
\title{Print Method for net_honem}
\usage{
\method{print}{net_honem}(x, ...)
}
\arguments{
\item{x}{A \code{net_honem} object.}

\item{...}{Additional arguments (ignored).}
}
\value{
The input object, invisibly.
}
\description{
Print Method for net_honem
}
\examples{
seqs <- list(c("A","B","C","D"), c("A","B","C","A"), c("B","C","D","A"))
hem <- build_honem(build_hon(seqs, max_order = 2), dim = 2)
print(hem)

\donttest{
seqs <- data.frame(
  V1 = c("A","B","C","A","B"),
  V2 = c("B","C","A","B","C"),
  V3 = c("C","A","B","C","A")
)
hon   <- build_hon(seqs, max_order = 2L)
honem <- build_honem(hon, dim = 2L)
print(honem)
}

}
