% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/mmm.R
\name{print.mmm_compare}
\alias{print.mmm_compare}
\title{Print Method for mmm_compare}
\usage{
\method{print}{mmm_compare}(x, ...)
}
\arguments{
\item{x}{An \code{mmm_compare} object.}

\item{...}{Unsupported. Supplying unused arguments raises an error.}
}
\value{
The input object, invisibly.
}
\description{
Print Method for mmm_compare
}
\examples{
seqs <- data.frame(V1 = sample(c("A","B","C"), 30, TRUE),
                   V2 = sample(c("A","B","C"), 30, TRUE))
cmp <- compare_mmm(seqs, k = 2:3, n_starts = 1, max_iter = 10, seed = 1)
print(cmp)
\donttest{
set.seed(1)
seqs <- data.frame(
  V1 = sample(c("A","B","C"), 30, TRUE),
  V2 = sample(c("A","B","C"), 30, TRUE),
  V3 = sample(c("A","B","C"), 30, TRUE)
)
cmp <- compare_mmm(seqs, k = 2:3, n_starts = 5, seed = 1)
print(cmp)
}

}
