% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/vertex_bootstrap.R
\name{plot.net_vertex_comparison}
\alias{plot.net_vertex_comparison}
\title{Plot a Two-Network Vertex-Bootstrap Comparison}
\usage{
\method{plot}{net_vertex_comparison}(x, ...)
}
\arguments{
\item{x}{A \code{net_vertex_comparison} object.}

\item{...}{Additional arguments (ignored).}
}
\value{
A ggplot object.
}
\description{
Forest plot of the statistic differences with normal-approximation
confidence intervals; differences whose interval excludes zero are the
statistically distinguishable ones.
}
