% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/hon.R
\name{summary.net_hon}
\alias{summary.net_hon}
\title{Summary Method for net_hon}
\usage{
\method{summary}{net_hon}(object, ...)
}
\arguments{
\item{object}{A \code{net_hon} object.}

\item{...}{Additional arguments (ignored).}
}
\value{
The edge data.frame \code{object$edges} (columns \code{path},
\code{from}, \code{to}, \code{count}, \code{probability},
\code{from_order}, \code{to_order}), returned visibly; the summary text
is printed as a side effect.
}
\description{
Summary Method for net_hon
}
\examples{
seqs <- list(c("A","B","C","D"), c("A","B","C","A"), c("B","C","D","A"))
hon <- build_hon(seqs, max_order = 2)
summary(hon)

\donttest{
seqs <- data.frame(
  V1 = c("A","B","C","A","B"),
  V2 = c("B","C","A","B","C"),
  V3 = c("C","A","B","C","A")
)
hon <- build_hon(seqs, max_order = 2L)
summary(hon)
}

}
