% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/simplicial.R
\name{print.persistent_homology}
\alias{print.persistent_homology}
\title{Print persistent homology results}
\usage{
\method{print}{persistent_homology}(x, ...)
}
\arguments{
\item{x}{A \code{persistent_homology} object.}

\item{...}{Additional arguments (unused).}
}
\value{
The input object, invisibly.
}
\description{
Print persistent homology results
}
\examples{
mat <- matrix(c(0,.6,.5,.6,0,.4,.5,.4,0), 3, 3)
colnames(mat) <- rownames(mat) <- c("A","B","C")
ph <- persistent_homology(mat, n_steps = 10)
print(ph)

}
