% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/reliability.R
\name{summary.net_reliability}
\alias{summary.net_reliability}
\title{Summary Method for net_reliability}
\usage{
\method{summary}{net_reliability}(object, ...)
}
\arguments{
\item{object}{A \code{net_reliability} object.}

\item{...}{Ignored.}
}
\value{
A tidy data frame with columns \code{model}, \code{metric},
\code{mean}, \code{sd} summarising the split-half iterations.
}
\description{
Summary Method for net_reliability
}
\examples{
net <- build_network(data.frame(V1 = c("A","B","C","A"),
  V2 = c("B","C","A","B")), method = "relative")
rel <- network_reliability(net, iter = 10)
\donttest{
seqs <- data.frame(
  V1 = sample(LETTERS[1:4], 30, TRUE), V2 = sample(LETTERS[1:4], 30, TRUE),
  V3 = sample(LETTERS[1:4], 30, TRUE), V4 = sample(LETTERS[1:4], 30, TRUE)
)
net <- build_network(seqs, method = "relative")
rel <- network_reliability(net, iter = 100, seed = 42)
print(rel)
}

}
