% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/simplicial.R
\name{print.simplicial_complex}
\alias{print.simplicial_complex}
\title{Print a simplicial complex}
\usage{
\method{print}{simplicial_complex}(x, ...)
}
\arguments{
\item{x}{A \code{simplicial_complex} object.}

\item{...}{Additional arguments (unused).}
}
\value{
The input object, invisibly.
}
\description{
Print a simplicial complex
}
\examples{
mat <- matrix(c(0,.6,.5,.6,0,.4,.5,.4,0), 3, 3)
colnames(mat) <- rownames(mat) <- c("A","B","C")
sc <- build_simplicial(mat, threshold = 0.3)
print(sc)

}
