% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/gimme.R
\name{print.net_gimme}
\alias{print.net_gimme}
\title{Print Method for net_gimme}
\usage{
\method{print}{net_gimme}(x, ...)
}
\arguments{
\item{x}{A \code{net_gimme} object.}

\item{...}{Additional arguments (ignored).}
}
\value{
The input object, invisibly.
}
\description{
Print Method for net_gimme
}
\examples{
\dontshow{if (requireNamespace("lavaan", quietly = TRUE)) withAutoprint(\{ # examplesIf}
\donttest{
set.seed(1)
panel <- data.frame(
  id = rep(1:5, each = 20),
  t  = rep(seq_len(20), 5),
  A  = rnorm(100), B = rnorm(100), C = rnorm(100)
)
gm <- build_gimme(panel, vars = c("A","B","C"), id = "id", time = "t")
print(gm)
}
\dontshow{\}) # examplesIf}
}
