% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/association_rules.R
\name{print.net_association_rules}
\alias{print.net_association_rules}
\title{Print Method for net_association_rules}
\usage{
\method{print}{net_association_rules}(x, ...)
}
\arguments{
\item{x}{A \code{net_association_rules} object.}

\item{...}{Additional arguments (ignored).}
}
\value{
The input object, invisibly.
}
\description{
Print Method for net_association_rules
}
\examples{
trans <- list(c("A","B","C"), c("A","B"), c("B","C","D"), c("A","C","D"))
rules <- association_rules(trans, min_support = 0.3, min_confidence = 0.5,
                           min_lift = 0)
print(rules)

}
