% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/transition_entropy.R
\name{print.summary.net_transition_entropy}
\alias{print.summary.net_transition_entropy}
\title{Print method for \code{summary.net_transition_entropy}}
\usage{
\method{print}{summary.net_transition_entropy}(x, digits = 3, ...)
}
\arguments{
\item{x}{A \code{summary.net_transition_entropy}.}

\item{digits}{Integer. Digits to round numeric output. Default \code{3}.}

\item{...}{Ignored.}
}
\value{
\code{x} invisibly.
}
\description{
Print method for \code{summary.net_transition_entropy}
}
