% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/mogen.R
\name{plot.net_mogen}
\alias{plot.net_mogen}
\title{Plot Method for net_mogen}
\usage{
\method{plot}{net_mogen}(x, type = c("ic", "likelihood"), ...)
}
\arguments{
\item{x}{A \code{net_mogen} object.}

\item{type}{Character. Plot type: \code{"ic"} (default) or \code{"likelihood"}.}

\item{...}{Additional arguments passed to \code{\link[graphics]{plot}}.}
}
\value{
The input object, invisibly.
}
\description{
Plot Method for net_mogen
}
\examples{
seqs <- list(c("A","B","C","D"), c("A","B","C","A"), c("B","C","D","A"))
mg <- build_mogen(seqs, max_order = 2)
plot(mg)

\donttest{
seqs <- data.frame(
  V1 = c("A","B","C","A","B"),
  V2 = c("B","C","A","B","C"),
  V3 = c("C","A","B","C","A")
)
mog <- build_mogen(seqs, max_order = 2L)
plot(mog, type = "ic")
}

}
