% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/mogen.R
\name{print.net_mogen}
\alias{print.net_mogen}
\title{Print Method for net_mogen}
\usage{
\method{print}{net_mogen}(x, ...)
}
\arguments{
\item{x}{A \code{net_mogen} object.}

\item{...}{Additional arguments (ignored).}
}
\value{
The input object, invisibly.
}
\description{
Print Method for net_mogen
}
\examples{
seqs <- list(c("A","B","C","D"), c("A","B","C","A"), c("B","C","D","A"))
mg <- build_mogen(seqs, max_order = 2)
print(mg)

\donttest{
seqs <- data.frame(
  V1 = c("A","B","C","A","B"),
  V2 = c("B","C","A","B","C"),
  V3 = c("C","A","B","C","A")
)
mog <- build_mogen(seqs, max_order = 2L)
print(mog)
}

}
