% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/nct.R
\name{print.net_nct}
\alias{print.net_nct}
\title{Print Method for net_nct}
\usage{
\method{print}{net_nct}(x, ...)
}
\arguments{
\item{x}{A \code{net_nct} object.}

\item{...}{Ignored.}
}
\value{
The input object, invisibly.
}
\description{
Print Method for net_nct
}
\examples{
\dontrun{
set.seed(1)
x1 <- matrix(rnorm(200 * 5), 200, 5)
x2 <- matrix(rnorm(200 * 5), 200, 5)
colnames(x1) <- colnames(x2) <- paste0("V", 1:5)
res <- nct(x1, x2, iter = 100)
res$M$p_value
res$S$p_value
}
}
