% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/honem.R
\name{summary.net_honem}
\alias{summary.net_honem}
\title{Summary Method for net_honem}
\usage{
\method{summary}{net_honem}(object, ...)
}
\arguments{
\item{object}{A \code{net_honem} object.}

\item{...}{Additional arguments (ignored).}
}
\value{
A data.frame with one row per node: column \code{node} (node
label) followed by \code{dim1}, \code{dim2}, ..., \code{dim}\emph{d}
embedding coordinates, returned visibly; the summary text is printed as
a side effect.
}
\description{
Summary Method for net_honem
}
\examples{
seqs <- list(c("A","B","C","D"), c("A","B","C","A"), c("B","C","D","A"))
hem <- build_honem(build_hon(seqs, max_order = 2), dim = 2)
summary(hem)

\donttest{
seqs <- list(c("A","B","C","D"), c("A","B","C","A"), c("B","C","D","A"))
hon <- build_hon(seqs, max_order = 3)
he <- build_honem(hon, dim = 2)
summary(he)
}

}
