% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/path_dependence.R
\name{summary.net_path_dependence}
\alias{summary.net_path_dependence}
\title{Summary method for \code{net_path_dependence}}
\usage{
\method{summary}{net_path_dependence}(object, ...)
}
\arguments{
\item{object}{A \code{net_path_dependence} object.}

\item{...}{Ignored.}
}
\value{
A \code{summary.net_path_dependence} with the full sorted table and
chain-level summaries.
}
\description{
Summary method for \code{net_path_dependence}
}
