% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/utils.R
\name{utils}
\alias{utils}
\title{Internal Helper Functions for Nestimate}
\description{
Internal utility functions used by other Nestimate functions.
}
\keyword{internal}
