% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/data.R
\docType{data}
\name{chatgpt_srl}
\alias{chatgpt_srl}
\title{ChatGPT Self-Regulated Learning Scale Scores}
\format{
A data frame with 1,000 rows and 5 columns:
\describe{
\item{CSU}{Numeric. Comprehension and Study Understanding scale mean.}
\item{IV}{Numeric. Intrinsic Value scale mean.}
\item{SE}{Numeric. Self-Efficacy scale mean.}
\item{SR}{Numeric. Self-Regulation scale mean.}
\item{TA}{Numeric. Task Avoidance scale mean.}
}
}
\source{
Vogelsmeier, L.V.D.E., Oliveira, E., Misiejuk, K.,
Lopez-Pernas, S., & Saqr, M. (2025). Delving into the psychology of
Machines: Exploring the structure of self-regulated learning via
LLM-generated survey responses. \emph{Computers in Human Behavior},
173, 108769. \doi{10.1016/j.chb.2025.108769}
}
\usage{
chatgpt_srl
}
\description{
Scale scores on five self-regulated learning (SRL) constructs for 1,000
responses generated by ChatGPT to a validated SRL questionnaire. Part of a
larger dataset comparing LLM-generated responses to human norms across seven
large language models.
}
\examples{
net <- build_network(chatgpt_srl, method = "glasso",
                     params = list(gamma = 0.5))
net

}
\keyword{datasets}
