% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/bootstrap_network.R
\name{print.wtna_boot_mixed}
\alias{print.wtna_boot_mixed}
\title{Print Method for wtna_boot_mixed}
\usage{
\method{print}{wtna_boot_mixed}(x, ...)
}
\arguments{
\item{x}{A \code{wtna_boot_mixed} object.}

\item{...}{Additional arguments (ignored).}
}
\value{
The input object, invisibly.
}
\description{
Print Method for wtna_boot_mixed
}
\examples{
oh <- data.frame(A = c(1,0,1,0), B = c(0,1,0,1), C = c(1,1,0,0))
mixed <- wtna(oh, method = "both")
boot  <- bootstrap_network(mixed, iter = 10)
print(boot)
\donttest{
set.seed(1)
oh <- data.frame(
  A = c(1,0,1,0,1,0,1,0),
  B = c(0,1,0,1,0,1,0,1),
  C = c(1,1,0,0,1,1,0,0)
)
mixed <- wtna(oh, method = "both")
boot  <- bootstrap_network(mixed, iter = 20)
print(boot)
}

}
