% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/prepare_data.R
\name{print.nestimate_data}
\alias{print.nestimate_data}
\title{Print Method for nestimate_data}
\usage{
\method{print}{nestimate_data}(x, ...)
}
\arguments{
\item{x}{A \code{nestimate_data} object.}

\item{...}{Additional arguments (ignored).}
}
\value{
The input object, invisibly.
}
\description{
Print Method for nestimate_data
}
\examples{
events <- data.frame(
  actor  = c("u1","u1","u1","u2","u2","u2"),
  action = c("A","B","C","B","A","C"),
  time   = c(1,2,3,1,2,3)
)
nd <- prepare(events, action = "action",
              actor = "actor", time = "time")
print(nd)
}
