% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/simplicial.R
\name{print.q_analysis}
\alias{print.q_analysis}
\title{Print Q-analysis results}
\usage{
\method{print}{q_analysis}(x, ...)
}
\arguments{
\item{x}{A \code{q_analysis} object.}

\item{...}{Additional arguments (unused).}
}
\value{
The input object, invisibly.
}
\description{
Print Q-analysis results
}
\examples{
mat <- matrix(c(0,.6,.5,.6,0,.4,.5,.4,0), 3, 3)
colnames(mat) <- rownames(mat) <- c("A","B","C")
sc <- build_simplicial(mat, threshold = 0.3)
qa <- q_analysis(sc)
print(qa)

}
