% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/wtna.R
\name{print.wtna_mixed}
\alias{print.wtna_mixed}
\title{Print Method for wtna_mixed}
\usage{
\method{print}{wtna_mixed}(x, ...)
}
\arguments{
\item{x}{A \code{wtna_mixed} object.}

\item{...}{Additional arguments (ignored).}
}
\value{
The input object, invisibly.
}
\description{
Print Method for wtna_mixed
}
\examples{
oh <- matrix(c(1,0,0, 0,1,0, 0,0,1, 1,0,0), nrow = 4, byrow = TRUE,
             dimnames = list(NULL, c("A","B","C")))
mixed <- wtna(oh, method = "both")
print(mixed)

\donttest{
oh <- data.frame(
  A = c(1,0,1,0,1,0,1,0),
  B = c(0,1,0,1,0,1,0,1),
  C = c(1,1,0,0,1,1,0,0)
)
mixed <- wtna(oh, method = "both")
print(mixed)
}
}
