% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/bayes_compare.R
\name{print.net_bayes_group}
\alias{print.net_bayes_group}
\title{Print method for net_bayes_group}
\usage{
\method{print}{net_bayes_group}(x, ...)
}
\arguments{
\item{x}{A \code{net_bayes_group} object.}

\item{...}{Additional arguments (ignored).}
}
\value{
The input object, invisibly.
}
\description{
Print method for net_bayes_group
}
\examples{
s <- data.frame(V1 = c("A","B","A","C"), V2 = c("B","C","B","A"),
                grp = c("X","X","Y","Y"))
nets <- build_network(s, method = "relative", group = "grp")
print(bayes_compare(nets, draws = 200, seed = 1))
}
