% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/permutation_test.R
\name{summary.wtna_perm_mixed}
\alias{summary.wtna_perm_mixed}
\title{Summary Method for wtna_perm_mixed}
\usage{
\method{summary}{wtna_perm_mixed}(object, ...)
}
\arguments{
\item{object}{A \code{wtna_perm_mixed} object.}

\item{...}{Additional arguments (ignored).}
}
\value{
A list with transition and co-occurrence permutation summaries.
}
\description{
Summary Method for wtna_perm_mixed
}
