% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/permutation_test.R
\name{summary.net_permutation_group}
\alias{summary.net_permutation_group}
\title{Summary Method for net_permutation_group}
\usage{
\method{summary}{net_permutation_group}(object, ...)
}
\arguments{
\item{object}{A \code{net_permutation_group} object.}

\item{...}{Additional arguments (ignored).}
}
\value{
A data frame with group, edge, p_value, and sig columns.
}
\description{
Returns a combined summary data frame across all groups.
}
\examples{
s1 <- data.frame(V1 = c("A","B","A","C"), V2 = c("B","C","B","A"),
  V3 = c("C","A","C","B"), grp = c("X","X","Y","Y"))
s2 <- data.frame(V1 = c("C","A","C","B"), V2 = c("A","B","A","C"),
  V3 = c("B","C","B","A"), grp = c("X","X","Y","Y"))
nets1 <- build_network(s1, method = "relative", group = "grp")
nets2 <- build_network(s2, method = "relative", group = "grp")
perm  <- permutation(nets1, nets2, iter = 10)
summary(perm)
\donttest{
set.seed(1)
s1 <- data.frame(V1 = c("A","B","A","C"), V2 = c("B","C","B","A"),
                 V3 = c("C","A","C","B"), grp = c("X","X","Y","Y"))
s2 <- data.frame(V1 = c("C","A","C","B"), V2 = c("A","B","A","C"),
                 V3 = c("B","C","B","A"), grp = c("X","X","Y","Y"))
nets1 <- build_network(s1, method = "relative", group = "grp")
nets2 <- build_network(s2, method = "relative", group = "grp")
perm  <- permutation(nets1, nets2, iter = 20, seed = 1)
summary(perm)
}
}
