% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/link_prediction.R
\name{summary.net_link_prediction}
\alias{summary.net_link_prediction}
\title{Summary Method for net_link_prediction}
\usage{
\method{summary}{net_link_prediction}(object, ...)
}
\arguments{
\item{object}{A \code{net_link_prediction} object.}

\item{...}{Additional arguments (ignored).}
}
\value{
A data frame with per-method summary statistics, invisibly.
}
\description{
Summary Method for net_link_prediction
}
\examples{
seqs <- data.frame(
  V1 = sample(LETTERS[1:4], 30, TRUE),
  V2 = sample(LETTERS[1:4], 30, TRUE),
  V3 = sample(LETTERS[1:4], 30, TRUE)
)
net <- build_network(seqs, method = "relative")
pred <- predict_links(net)
summary(pred)

}
