% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/markov_order.R
\name{print.net_markov_order}
\alias{print.net_markov_order}
\title{Print Method for net_markov_order}
\usage{
\method{print}{net_markov_order}(x, ...)
}
\arguments{
\item{x}{A \code{net_markov_order} object.}

\item{...}{Ignored.}
}
\value{
The input object, invisibly.
}
\description{
Print Method for net_markov_order
}
\examples{
\donttest{
# First-order Markov data: test should select order 1
set.seed(1)
states <- letters[1:4]
tm <- matrix(runif(16), 4, 4, dimnames = list(states, states))
tm <- tm / rowSums(tm)
seqs <- lapply(1:30, function(.) {
  s <- character(50); s[1] <- sample(states, 1)
  for (i in 2:50) s[i] <- sample(states, 1, prob = tm[s[i - 1], ])
  s
})
res <- markov_order_test(seqs, max_order = 3, n_perm = 300, seed = 1)
res$optimal_order
summary(res)
plot(res)
}
}
