% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/mcml.R
\name{.process_weights}
\alias{.process_weights}
\title{Process weights based on type}
\usage{
.process_weights(raw_weights, type, directed = TRUE)
}
\description{
Process weights based on type
}
\keyword{internal}
