% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/permutation_test.R
\name{summary.net_permutation}
\alias{summary.net_permutation}
\title{Summary Method for net_permutation}
\usage{
\method{summary}{net_permutation}(object, ...)
}
\arguments{
\item{object}{A \code{net_permutation} object.}

\item{...}{Additional arguments (ignored).}
}
\value{
A data frame with edge-level permutation test results.
}
\description{
Summary Method for net_permutation
}
\examples{
s1 <- data.frame(V1 = c("A","B","C"), V2 = c("B","C","A"))
s2 <- data.frame(V1 = c("A","C","B"), V2 = c("C","B","A"))
n1 <- build_network(s1, method = "relative")
n2 <- build_network(s2, method = "relative")
perm <- permutation(n1, n2, iter = 10)
summary(perm)
\donttest{
set.seed(1)
d1 <- data.frame(V1 = c("A","B","A"), V2 = c("B","C","B"),
                 V3 = c("C","A","C"))
d2 <- data.frame(V1 = c("C","A","C"), V2 = c("A","B","A"),
                 V3 = c("B","C","B"))
net1 <- build_network(d1, method = "relative")
net2 <- build_network(d2, method = "relative")
perm <- permutation(net1, net2, iter = 20, seed = 1)
summary(perm)
}

}
