% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/mcml.R
\name{print.mcml}
\alias{print.mcml}
\title{Print Method for mcml}
\usage{
\method{print}{mcml}(x, ...)
}
\arguments{
\item{x}{An \code{mcml} object.}

\item{...}{Unsupported. Supplying unused arguments raises an error.}
}
\value{
The input object, invisibly.
}
\description{
Print Method for mcml
}
\examples{
seqs <- data.frame(V1 = c("A","B","C","A"), V2 = c("B","C","A","B"))
clusters <- list(G1 = c("A","B"), G2 = c("C"))
cs <- build_mcml(seqs, clusters)
print(cs)
\donttest{
seqs <- data.frame(
  T1 = c("A","B","A"), T2 = c("B","C","B"),
  T3 = c("C","A","C"), T4 = c("A","B","A")
)
clusters <- c("Alpha", "Beta", "Alpha")
cs <- build_mcml(seqs, clusters, type = "raw")
print(cs)
}

}
