% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/build_network.R
\name{print.netobject}
\alias{print.netobject}
\title{Print Method for Network Object}
\usage{
\method{print}{netobject}(x, ...)
}
\arguments{
\item{x}{A \code{netobject}.}

\item{...}{Additional arguments (ignored).}
}
\value{
The input object, invisibly.
}
\description{
Print Method for Network Object
}
\examples{
seqs <- data.frame(V1 = c("A","B","C","A"), V2 = c("B","C","A","B"))
net <- build_network(seqs, method = "relative")
print(net)
\donttest{
seqs <- data.frame(
  V1 = c("A","B","A","C"), V2 = c("B","C","B","A"),
  V3 = c("C","A","C","B")
)
net <- build_network(seqs, method = "relative")
print(net)
}

}
