% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/mcml.R
\name{.build_cluster_lookup}
\alias{.build_cluster_lookup}
\title{Build node-to-cluster lookup from cluster specification}
\usage{
.build_cluster_lookup(clusters, all_nodes)
}
\description{
Build node-to-cluster lookup from cluster specification
}
\keyword{internal}
