% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/association_rules.R
\name{summary.net_association_rules}
\alias{summary.net_association_rules}
\title{Summary Method for net_association_rules}
\usage{
\method{summary}{net_association_rules}(object, ...)
}
\arguments{
\item{object}{A \code{net_association_rules} object.}

\item{...}{Additional arguments (ignored).}
}
\value{
A data frame summarizing the rules, invisibly.
}
\description{
Summary Method for net_association_rules
}
\examples{
trans <- list(c("A","B","C"), c("A","B"), c("B","C","D"), c("A","C","D"))
rules <- association_rules(trans, min_support = 0.3, min_confidence = 0.5,
                           min_lift = 0)
summary(rules)

}
