% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/vertex_bootstrap.R
\name{summary.net_vertex_bootstrap}
\alias{summary.net_vertex_bootstrap}
\title{Summarize a Vertex Bootstrap Result}
\usage{
\method{summary}{net_vertex_bootstrap}(object, ...)
}
\arguments{
\item{object}{A \code{net_vertex_bootstrap} object.}

\item{...}{Additional arguments (ignored).}
}
\value{
The tidy summary data frame (one row per statistic).
}
\description{
Summarize a Vertex Bootstrap Result
}
