% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/path_dependence.R
\name{print.summary.net_path_dependence}
\alias{print.summary.net_path_dependence}
\title{Print method for \code{summary.net_path_dependence}}
\usage{
\method{print}{summary.net_path_dependence}(x, digits = 3L, ...)
}
\arguments{
\item{x}{A \code{summary.net_path_dependence} object.}

\item{digits}{Integer. Digits to round numeric output. Default 3.}

\item{...}{Ignored.}
}
\value{
\code{x} invisibly.
}
\description{
Print method for \code{summary.net_path_dependence}
}
