% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/bootstrap_network.R
\name{summary.wtna_boot_mixed}
\alias{summary.wtna_boot_mixed}
\title{Summary Method for wtna_boot_mixed}
\usage{
\method{summary}{wtna_boot_mixed}(object, ...)
}
\arguments{
\item{object}{A \code{wtna_boot_mixed} object.}

\item{...}{Additional arguments (ignored).}
}
\value{
A list with \code{$transition} and \code{$cooccurrence} summary data frames.
}
\description{
Summary Method for wtna_boot_mixed
}
\examples{
oh <- data.frame(A = c(1,0,1,0), B = c(0,1,0,1), C = c(1,1,0,0))
mixed <- wtna(oh, method = "both")
boot  <- bootstrap_network(mixed, iter = 10)
summary(boot)
\donttest{
set.seed(1)
oh <- data.frame(
  A = c(1,0,1,0,1,0,1,0),
  B = c(0,1,0,1,0,1,0,1),
  C = c(1,1,0,0,1,1,0,0)
)
mixed <- wtna(oh, method = "both")
boot  <- bootstrap_network(mixed, iter = 20)
summary(boot)
}

}
