% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/honem.R
\name{plot.net_honem}
\alias{plot.net_honem}
\title{Plot Method for net_honem}
\usage{
\method{plot}{net_honem}(x, dims = c(1L, 2L), ...)
}
\arguments{
\item{x}{A \code{net_honem} object.}

\item{dims}{Integer vector of length 2. Dimensions to plot (default: \code{c(1, 2)}).}

\item{...}{Additional arguments passed to \code{\link[graphics]{plot}}.}
}
\value{
The input object, invisibly.
}
\description{
Plot Method for net_honem
}
\examples{
seqs <- list(c("A","B","C","D"), c("A","B","C","A"), c("B","C","D","A"))
hem <- build_honem(build_hon(seqs, max_order = 2), dim = 2)
plot(hem)

\donttest{
seqs <- list(c("A","B","C","D"), c("A","B","C","A"), c("B","C","D","A"))
hon <- build_hon(seqs, max_order = 3)
he <- build_honem(hon, dim = 2)
plot(he)
}

}
