% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/bootstrap_network.R
\name{print.net_bootstrap_group}
\alias{print.net_bootstrap_group}
\title{Print Method for net_bootstrap_group}
\usage{
\method{print}{net_bootstrap_group}(x, ...)
}
\arguments{
\item{x}{A \code{net_bootstrap_group} object.}

\item{...}{Ignored.}
}
\value{
\code{x} invisibly.
}
\description{
Print Method for net_bootstrap_group
}
\examples{
seqs <- data.frame(V1 = c("A","B","A","C"), V2 = c("B","C","C","A"),
  V3 = c("C","A","B","B"), grp = c("X","X","Y","Y"))
nets <- build_network(seqs, method = "relative", group = "grp")
boot <- bootstrap_network(nets, iter = 10)
print(boot)
\donttest{
set.seed(1)
seqs <- data.frame(
  V1 = c("A","B","A","C","B","A"),
  V2 = c("B","C","B","A","C","B"),
  V3 = c("C","A","C","B","A","C"),
  grp = c("X","X","X","Y","Y","Y")
)
nets <- build_network(seqs, method = "relative", group = "grp")
boot <- bootstrap_network(nets, iter = 20)
print(boot)
}
}
