% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/vertex_bootstrap.R
\name{summary.net_vertex_comparison}
\alias{summary.net_vertex_comparison}
\title{Summarize a Two-Network Vertex-Bootstrap Comparison}
\usage{
\method{summary}{net_vertex_comparison}(object, ...)
}
\arguments{
\item{object}{A \code{net_vertex_comparison} object.}

\item{...}{Additional arguments (ignored).}
}
\value{
The tidy summary data frame (one row per statistic).
}
\description{
Summarize a Two-Network Vertex-Bootstrap Comparison
}
