% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/boot_glasso.R
\name{print.boot_glasso}
\alias{print.boot_glasso}
\title{Print Method for boot_glasso}
\usage{
\method{print}{boot_glasso}(x, ...)
}
\arguments{
\item{x}{A \code{boot_glasso} object.}

\item{...}{Additional arguments (ignored).}
}
\value{
The input object, invisibly.
}
\description{
Print Method for boot_glasso
}
\examples{
set.seed(1)
dat <- as.data.frame(matrix(rnorm(60), ncol = 3))
bg <- boot_glasso(dat, iter = 10, cs_iter = 5, centrality = "strength")
print(bg)
\donttest{
set.seed(42)
mat <- matrix(rnorm(60), ncol = 4)
colnames(mat) <- LETTERS[1:4]
boot <- boot_glasso(as.data.frame(mat), iter = 20, cs_iter = 10,
  centrality = "strength", seed = 42)
print(boot)
}

}
