% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/mcml.R
\name{.build_mcml_edgelist}
\alias{.build_mcml_edgelist}
\title{Build MCML from edge list data.frame}
\usage{
.build_mcml_edgelist(df, clusters, method, type, directed, compute_within)
}
\description{
Build MCML from edge list data.frame
}
\keyword{internal}
