% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/bootstrap_network.R
\name{print.net_bootstrap}
\alias{print.net_bootstrap}
\title{Print Method for net_bootstrap}
\usage{
\method{print}{net_bootstrap}(x, ...)
}
\arguments{
\item{x}{A \code{net_bootstrap} object.}

\item{...}{Additional arguments (ignored).}
}
\value{
The input object, invisibly.
}
\description{
Print Method for net_bootstrap
}
\examples{
net <- build_network(data.frame(V1 = c("A","B","C"), V2 = c("B","C","A")),
  method = "relative")
boot <- bootstrap_network(net, iter = 10)
print(boot)
\donttest{
set.seed(1)
seqs <- data.frame(
  V1 = c("A","B","A","C","B"), V2 = c("B","C","B","A","C"),
  V3 = c("C","A","C","B","A")
)
net  <- build_network(seqs, method = "relative")
boot <- bootstrap_network(net, iter = 20)
print(boot)
}

}
