% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/estimator_registry.R
\name{list_estimators}
\alias{list_estimators}
\title{List All Registered Estimators}
\usage{
list_estimators()
}
\value{
A data frame with columns \code{name}, \code{description},
\code{directed}.
}
\description{
Return a data frame summarising all registered network estimators.
}
\examples{
list_estimators()

}
\seealso{
\code{\link{register_estimator}}, \code{\link{get_estimator}}
}
