% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/markov.R
\name{print.net_markov_stability_group}
\alias{print.net_markov_stability_group}
\title{Print method for \code{net_markov_stability_group}}
\usage{
\method{print}{net_markov_stability_group}(x, ...)
}
\arguments{
\item{x}{A \code{net_markov_stability_group} (named list of
\code{net_markov_stability} results).}

\item{...}{Forwarded to \code{print.net_markov_stability} for each element.}
}
\value{
\code{x} invisibly.
}
\description{
Print method for \code{net_markov_stability_group}
}
