% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/build_network.R
\name{print.netobject_ml}
\alias{print.netobject_ml}
\title{Print Method for Multilevel Network Object}
\usage{
\method{print}{netobject_ml}(x, ...)
}
\arguments{
\item{x}{A \code{netobject_ml}.}

\item{...}{Additional arguments (ignored).}
}
\value{
The input object, invisibly.
}
\description{
Print Method for Multilevel Network Object
}
\examples{
set.seed(1)
obs <- data.frame(id = rep(1:3, each = 5),
                  A = rnorm(15), B = rnorm(15), C = rnorm(15))
net_ml <- build_network(obs, method = "cor",
                         params = list(id = "id"), level = "both")
print(net_ml)
\donttest{
set.seed(1)
obs <- data.frame(
  id  = rep(1:5, each = 8),
  A   = rnorm(40), B = rnorm(40),
  C   = rnorm(40), D = rnorm(40)
)
net_ml <- build_network(obs, method = "cor",
                         params = list(id = "id"), level = "both")
print(net_ml)
}

}
