% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/gimme.R
\name{plot.net_gimme}
\alias{plot.net_gimme}
\title{Plot Method for net_gimme}
\usage{
\method{plot}{net_gimme}(
  x,
  type = c("temporal", "contemporaneous", "individual", "counts", "fit"),
  subject = NULL,
  ...
)
}
\arguments{
\item{x}{A \code{net_gimme} object.}

\item{type}{Character. Plot type: \code{"temporal"}, \code{"contemporaneous"},
\code{"individual"}, \code{"counts"}, or \code{"fit"}.}

\item{subject}{Integer or character. Subject to plot for \code{type = "individual"}.}

\item{...}{Additional arguments (ignored).}
}
\value{
The input object, invisibly.
}
\description{
Plot Method for net_gimme
}
\examples{
\dontshow{if (requireNamespace("lavaan", quietly = TRUE)) withAutoprint(\{ # examplesIf}
\donttest{
set.seed(1)
panel <- data.frame(
  id = rep(1:5, each = 20),
  t  = rep(seq_len(20), 5),
  A  = rnorm(100), B = rnorm(100), C = rnorm(100)
)
gm <- build_gimme(panel, vars = c("A","B","C"), id = "id", time = "t")
plot(gm, type = "temporal")
}
\dontshow{\}) # examplesIf}
}
