% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/permutation_test.R
\name{print.wtna_perm_mixed}
\alias{print.wtna_perm_mixed}
\title{Print Method for wtna_perm_mixed}
\usage{
\method{print}{wtna_perm_mixed}(x, ...)
}
\arguments{
\item{x}{A \code{wtna_perm_mixed} object.}

\item{...}{Additional arguments (ignored).}
}
\value{
The input object, invisibly.
}
\description{
Print Method for wtna_perm_mixed
}
