% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/certainty.R
\name{print.net_certainty}
\alias{print.net_certainty}
\title{Print Method for net_certainty}
\usage{
\method{print}{net_certainty}(x, ...)
}
\arguments{
\item{x}{A \code{net_certainty} object.}

\item{...}{Additional arguments (ignored).}
}
\value{
The input object, invisibly.
}
\description{
Print Method for net_certainty
}
\examples{
seqs <- data.frame(V1 = c("A","B","C"), V2 = c("B","C","A"))
print(certainty(build_network(seqs, method = "relative")))
}
