% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/reliability.R
\name{print.net_reliability}
\alias{print.net_reliability}
\title{Print Method for net_reliability}
\usage{
\method{print}{net_reliability}(x, ...)
}
\arguments{
\item{x}{A \code{net_reliability} object.}

\item{...}{Additional arguments (ignored).}
}
\value{
The input object, invisibly.
}
\description{
Print Method for net_reliability
}
\examples{
net <- build_network(data.frame(V1 = c("A","B","C","A"),
  V2 = c("B","C","A","B")), method = "relative")
rel <- network_reliability(net, iter = 10)
print(rel)
\donttest{
set.seed(1)
seqs <- data.frame(
  V1 = sample(c("A","B","C"), 30, TRUE),
  V2 = sample(c("A","B","C"), 30, TRUE),
  V3 = sample(c("A","B","C"), 30, TRUE)
)
net <- build_network(seqs, method = "relative")
rel <- network_reliability(net, iter = 20, seed = 1)
print(rel)
}

}
