% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/bayes_compare.R
\name{print.net_bayes}
\alias{print.net_bayes}
\title{Print method for net_bayes}
\usage{
\method{print}{net_bayes}(x, ...)
}
\arguments{
\item{x}{A \code{net_bayes} object.}

\item{...}{Additional arguments (ignored).}
}
\value{
The input object, invisibly.
}
\description{
Print method for net_bayes
}
\examples{
s1 <- data.frame(V1 = c("A","B","C"), V2 = c("B","C","A"))
s2 <- data.frame(V1 = c("A","C","B"), V2 = c("C","B","A"))
b <- bayes_compare(build_network(s1, method = "relative"),
                   build_network(s2, method = "relative"),
                   draws = 500, seed = 1)
print(b)
}
