% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/cluster_data.R
\name{summary.net_clustering}
\alias{summary.net_clustering}
\title{Summary Method for net_clustering}
\usage{
\method{summary}{net_clustering}(object, ...)
}
\arguments{
\item{object}{A \code{net_clustering} object.}

\item{...}{Unsupported. Supplying unused arguments raises an error.}
}
\value{
The input object, invisibly.
}
\description{
Summary Method for net_clustering
}
\examples{
seqs <- data.frame(V1 = c("A","B","C","A","B"), V2 = c("B","C","A","B","A"),
                   V3 = c("C","A","B","C","B"))
cl <- build_clusters(seqs, k = 2)
summary(cl)
\donttest{
set.seed(1)
seqs <- data.frame(
  V1 = sample(c("A","B","C"), 20, TRUE),
  V2 = sample(c("A","B","C"), 20, TRUE),
  V3 = sample(c("A","B","C"), 20, TRUE)
)
cl <- build_clusters(seqs, k = 2)
summary(cl)
}

}
