% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/markov.R
\name{print.net_mpt_group}
\alias{print.net_mpt_group}
\title{Print method for \code{net_mpt_group}}
\usage{
\method{print}{net_mpt_group}(x, ...)
}
\arguments{
\item{x}{A \code{net_mpt_group} (named list of \code{net_mpt} results).}

\item{...}{Forwarded to \code{print.net_mpt} for each element.}
}
\value{
\code{x} invisibly.
}
\description{
Print method for \code{net_mpt_group}
}
