% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/link_prediction.R
\name{print.net_link_prediction}
\alias{print.net_link_prediction}
\title{Print Method for net_link_prediction}
\usage{
\method{print}{net_link_prediction}(x, ...)
}
\arguments{
\item{x}{A \code{net_link_prediction} object.}

\item{...}{Additional arguments (ignored).}
}
\value{
The input object, invisibly.
}
\description{
Print Method for net_link_prediction
}
\examples{
seqs <- data.frame(
  V1 = sample(LETTERS[1:4], 30, TRUE),
  V2 = sample(LETTERS[1:4], 30, TRUE),
  V3 = sample(LETTERS[1:4], 30, TRUE)
)
net <- build_network(seqs, method = "relative")
pred <- predict_links(net)
print(pred)

}
