% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/bayes_compare.R
\name{summary.net_bayes_group}
\alias{summary.net_bayes_group}
\title{Summary method for net_bayes_group}
\usage{
\method{summary}{net_bayes_group}(object, ...)
}
\arguments{
\item{object}{A \code{net_bayes_group} object.}

\item{...}{Additional arguments (ignored).}
}
\value{
A combined data frame with a \code{comparison} column.
}
\description{
Summary method for net_bayes_group
}
\examples{
s <- data.frame(V1 = c("A","B","A","C"), V2 = c("B","C","B","A"),
                grp = c("X","X","Y","Y"))
nets <- build_network(s, method = "relative", group = "grp")
summary(bayes_compare(nets, draws = 200, seed = 1))
}
