% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/mcml_pc.R
\name{summary.mcml_pc}
\alias{summary.mcml_pc}
\title{Summarize an MCML-PC Object}
\usage{
\method{summary}{mcml_pc}(object, ...)
}
\arguments{
\item{object}{An \code{mcml_pc} object.}

\item{...}{Additional arguments (ignored).}
}
\value{
Tidy data frame with one row per macro edge (upper triangle),
columns \code{from}, \code{to}, \code{weight}.
}
\description{
Summarize an MCML-PC Object
}
