% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/prune.R
\name{print.net_pruning_details}
\alias{print.net_pruning_details}
\title{Print method for pruning details}
\usage{
\method{print}{net_pruning_details}(x, ...)
}
\arguments{
\item{x}{A \code{net_pruning_details} object.}

\item{...}{Ignored.}
}
\value{
\code{x}, invisibly.
}
\description{
Print method for pruning details
}
