% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/hon.R
\name{print.net_hon}
\alias{print.net_hon}
\title{Print Method for net_hon}
\usage{
\method{print}{net_hon}(x, ...)
}
\arguments{
\item{x}{A \code{net_hon} object.}

\item{...}{Additional arguments (ignored).}
}
\value{
The input object, invisibly.
}
\description{
Print Method for net_hon
}
\examples{
seqs <- list(c("A","B","C","D"), c("A","B","C","A"), c("B","C","D","A"))
hon <- build_hon(seqs, max_order = 2)
print(hon)

\donttest{
seqs <- data.frame(
  V1 = c("A","B","C","A","B"),
  V2 = c("B","C","A","B","C"),
  V3 = c("C","A","B","C","A")
)
hon <- build_hon(seqs, max_order = 2L)
print(hon)
}

}
