% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/path_dependence.R
\name{print.net_path_dependence}
\alias{print.net_path_dependence}
\title{Print method for \code{net_path_dependence}}
\usage{
\method{print}{net_path_dependence}(x, top = 10L, digits = 3L, ...)
}
\arguments{
\item{x}{A \code{net_path_dependence} object.}

\item{top}{Integer. Number of top contexts to show. Default 10.}

\item{digits}{Integer. Digits to round numeric output. Default 3.}

\item{...}{Ignored.}
}
\value{
\code{x} invisibly.
}
\description{
Print method for \code{net_path_dependence}
}
