% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/bayes_compare.R
\name{summary.net_bayes}
\alias{summary.net_bayes}
\title{Summary method for net_bayes}
\usage{
\method{summary}{net_bayes}(object, ...)
}
\arguments{
\item{object}{A \code{net_bayes} object.}

\item{...}{Additional arguments (ignored).}
}
\value{
A data frame with edge-level posterior differences and intervals.
}
\description{
Summary method for net_bayes
}
\examples{
s1 <- data.frame(V1 = c("A","B","C"), V2 = c("B","C","A"))
s2 <- data.frame(V1 = c("A","C","B"), V2 = c("C","B","A"))
b <- bayes_compare(build_network(s1, method = "relative"),
                   build_network(s2, method = "relative"),
                   draws = 500, seed = 1)
summary(b)
}
