% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/centrality_stability.R
\name{print.net_stability}
\alias{print.net_stability}
\title{Print Method for net_stability}
\usage{
\method{print}{net_stability}(x, ...)
}
\arguments{
\item{x}{A \code{net_stability} object.}

\item{...}{Additional arguments (ignored).}
}
\value{
The input object, invisibly.
}
\description{
Print Method for net_stability
}
\examples{
net <- build_network(data.frame(V1 = c("A","B","C","A"),
  V2 = c("B","C","A","B")), method = "relative")
cs <- centrality_stability(net, iter = 10, drop_prop = 0.3)
print(cs)
\donttest{
set.seed(1)
seqs <- data.frame(
  V1 = sample(c("A","B","C"), 30, TRUE),
  V2 = sample(c("A","B","C"), 30, TRUE),
  V3 = sample(c("A","B","C"), 30, TRUE)
)
net <- build_network(seqs, method = "relative")
stab <- centrality_stability(net, measures = c("InStrength","OutStrength"),
                              iter = 10)
print(stab)
}

}
