% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/mcml_pc.R
\name{print.pc_loading_stability}
\alias{print.pc_loading_stability}
\title{Print Composite-Weight Stability}
\usage{
\method{print}{pc_loading_stability}(x, digits = 3, ...)
}
\arguments{
\item{x}{A \code{pc_loading_stability} object.}

\item{digits}{Number of digits to display (default 3).}

\item{...}{Additional arguments (ignored).}
}
\value{
\code{x}, invisibly.
}
\description{
Print Composite-Weight Stability
}
