% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/Nestimate-package.R
\docType{package}
\name{Nestimate-package}
\alias{Nestimate}
\alias{Nestimate-package}
\title{Nestimate: Network Estimation, Bootstrap, and Higher-Order Analysis}
\description{
\if{html}{\figure{logo.png}{options: style='float: right' alt='logo' width='120'}}

Estimate, compare, and analyze dynamic and psychological networks using a unified interface. Provides transition network analysis estimation (transition, frequency, co-occurrence, attention-weighted) Saqr et al. (2025) \doi{10.1145/3706468.3706513}, psychological network methods (correlation, partial correlation, 'graphical lasso', 'Ising') Saqr, Beck, and Lopez-Pernas (2024) \doi{10.1007/978-3-031-54464-4_19}, and higher-order network methods including higher-order networks, higher-order network embedding, hyper-path anomaly, and multi-order generative model. Supports bootstrap inference, permutation testing, split-half reliability, centrality stability analysis, mixed Markov models, multi-cluster multi-layer networks and clustering.
}
\seealso{
Useful links:
\itemize{
  \item \url{https://github.com/mohsaqr/Nestimate}
  \item \url{https://saqr.me/Nestimate/}
  \item Report bugs at \url{https://github.com/mohsaqr/Nestimate/issues}
}

}
\author{
\strong{Maintainer}: Mohammed Saqr \email{saqr@saqr.me} [copyright holder]

Authors:
\itemize{
  \item Sonsoles López-Pernas \email{sonsoles.lopez@uef.fi}
  \item Kamila Misiejuk \email{kamila.misiejuk@fernuni-hagen.de}
}

}
\keyword{internal}
