% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/compare_network.R
\name{compare_model.netobject_group}
\alias{compare_model.netobject_group}
\title{Compare two networks within a netobject_group}
\usage{
\method{compare_model}{netobject_group}(
  x,
  i = 1L,
  j = 2L,
  scaling = "none",
  measures = character(0),
  network = TRUE,
  ...
)
}
\arguments{
\item{x}{A \code{netobject_group}.}

\item{i}{Integer or character. Index or name of the first network.
Default \code{1L}.}

\item{j}{Integer or character. Index or name of the second network.
Default \code{2L}.}

\item{scaling}{See \code{compare_model()}.}

\item{measures}{See \code{compare_model()}.}

\item{network}{See \code{compare_model()}.}

\item{...}{Passed to \code{compare_model.netobject()}.}
}
\value{
A \code{net_comparison} object.
}
\description{
Selects two members of a \code{netobject_group} (by index or name) and
dispatches to \code{compare_model.netobject()}.
}
