% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/vertex_bootstrap.R
\name{print.net_vertex_comparison}
\alias{print.net_vertex_comparison}
\title{Print a Two-Network Vertex-Bootstrap Comparison}
\usage{
\method{print}{net_vertex_comparison}(x, digits = 3, ...)
}
\arguments{
\item{x}{A \code{net_vertex_comparison} object.}

\item{digits}{Number of digits to display (default 3).}

\item{...}{Additional arguments (ignored).}
}
\value{
\code{x}, invisibly.
}
\description{
Print a Two-Network Vertex-Bootstrap Comparison
}
