% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/centrality_stability.R
\name{print.net_stability_group}
\alias{print.net_stability_group}
\title{Print Method for net_stability_group}
\usage{
\method{print}{net_stability_group}(x, ...)
}
\arguments{
\item{x}{A \code{net_stability_group} (returned by \code{centrality_stability()}
when called on a \code{netobject_group} or an \code{mcml}).}

\item{...}{Additional arguments (ignored).}
}
\value{
The input \code{x} invisibly.
}
\description{
Print Method for net_stability_group
}
