% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/mcml_pc.R
\name{print.mcml_pc}
\alias{print.mcml_pc}
\title{Print an MCML-PC Object}
\usage{
\method{print}{mcml_pc}(x, digits = 3, ...)
}
\arguments{
\item{x}{An \code{mcml_pc} object.}

\item{digits}{Number of digits to display (default 3).}

\item{...}{Additional arguments (ignored).}
}
\value{
\code{x}, invisibly.
}
\description{
Print an MCML-PC Object
}
