% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/ph_distances.R
\name{plot.persistence_landscape}
\alias{plot.persistence_landscape}
\title{Plot Persistence Landscape}
\usage{
\method{plot}{persistence_landscape}(x, ...)
}
\arguments{
\item{x}{A \code{persistence_landscape} object.}

\item{...}{Ignored.}
}
\value{
A ggplot.
}
\description{
Plot Persistence Landscape
}
\examples{
\donttest{
mat <- matrix(c(0, .6, .5, .6, 0, .4, .5, .4, 0), 3, 3)
rownames(mat) <- colnames(mat) <- c("A","B","C")
ph <- persistent_homology(mat, n_steps = 5)
pl <- persistence_landscape(ph, k_max = 3, dimension = 0)
plot(pl)
}
}
