% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/estimate_network.R
\name{build_ising}
\alias{build_ising}
\title{Build an Ising Network}
\usage{
build_ising(data, ...)
}
\arguments{
\item{data}{Data frame (sequences or per-observation frequencies) or a
square symmetric matrix (correlation or covariance).}

\item{...}{Additional arguments passed to \code{\link{build_network}}.}
}
\value{
A \code{netobject} (see \code{\link{build_network}}).
}
\description{
Convenience wrapper for \code{build_network(method = "ising")}.
Computes L1-regularized logistic regression network for binary data.
}
\examples{
\donttest{
if (requireNamespace("glmnet", quietly = TRUE)) {
  bin_data <- data.frame(matrix(rbinom(200, 1, 0.5), ncol = 5))
  net <- build_ising(bin_data)
}
}
}
\seealso{
\code{\link{build_network}}
}
